@@ -16,3 +16,7 @@ class Chat(TelegramObject):
     @property
     def is_group(self) -> bool:
         return self.raw.type in [self.raw.GROUP, self.raw.SUPERGROUP]
+
+    @property
+    def id(self) -> int:  # noqa: A003
+        return self.raw.id
